==> Authlib-0.5.tar.gz: Authlib-0.5/authlib/specs/rfc6750/validator.py <==
"""
    authlib.rfc6750.validator
    ~~~~~~~~~~~~~~~~~~~~~~~~~

    Validate Bearer Token for in request, scope and token.

    :copyright: (c) 2017 by Hsiaoming Yang.
"""

import time
from ..rfc6749.util import scope_to_list
from .errors import (
    InvalidRequestError,
    InvalidTokenError,
    InsufficientScopeError
)


class BearerTokenValidator(object):
    def __init__(self, realm=None):
        self.realm = realm

    def request_invalid(self, method, uri, body, headers):
        raise NotImplementedError()

    def token_revoked(self, token):
        raise NotImplementedError()

    def token_expired(self, token):
        expires_at = token.get_expires_at()
        return expires_at < time.time()

    def scope_insufficient(self, token, scope):
        if not scope:
            return False
        token_scopes = set(scope_to_list(token.get_scope()))
        resource_scopes = set(scope_to_list(scope))
        return not token_scopes.issuperset(resource_scopes)

    def __call__(self, token, scope, method, uri, body, headers):
        if not token:
            raise InvalidTokenError(realm=self.realm)
        if self.request_invalid(method, uri, body, headers):
            raise InvalidRequestError()
        if self.token_expired(token):
            raise InvalidTokenError(realm=self.realm)
        if self.token_revoked(token):
            raise InvalidTokenError(realm=self.realm)
        if self.scope_insufficient(token, scope):
            raise InsufficientScopeError()

==> Authlib-0.6.tar.gz: Authlib-0.6/authlib/specs/rfc6750/validator.py <==
"""
    authlib.rfc6750.validator
    ~~~~~~~~~~~~~~~~~~~~~~~~~

    Validate Bearer Token for in request, scope and token.

    :copyright: (c) 2017 by Hsiaoming Yang.
    :license: LGPLv3, see LICENSE for more details.
"""

import time
from ..rfc6749.util import scope_to_list
from .errors import (
    InvalidRequestError,
    InvalidTokenError,
    InsufficientScopeError
)


class BearerTokenValidator(object):
    TOKEN_TYPE = 'bearer'

    def __init__(self, realm=None):
        self.realm = realm

    def authenticate_token(self, token_string):
        """
        :param token_string: A string to represent the access_token.
        :return: token
        """
        raise NotImplementedError()

    def request_invalid(self, request):
        raise NotImplementedError()

    def token_revoked(self, token):
        raise NotImplementedError()

    def token_expired(self, token):
        expires_at = token.get_expires_at()
        return expires_at < time.time()

    def scope_insufficient(self, token, scope):
        if not scope:
            return False
        token_scopes = set(scope_to_list(token.get_scope()))
        resource_scopes = set(scope_to_list(scope))
        return not token_scopes.issuperset(resource_scopes)

    def __call__(self, token_string, scope, request):
        token = self.authenticate_token(token_string)
        if not token:
            raise InvalidTokenError(realm=self.realm)
        if self.request_invalid(request):
            raise InvalidRequestError()
        if self.token_expired(token):
            raise InvalidTokenError(realm=self.realm)
        if self.token_revoked(token):
            raise InvalidTokenError(realm=self.realm)
        if self.scope_insufficient(token, scope):
            raise InsufficientScopeError()
        return token
